#ifndef _MAX696x_CONF_H_
#define _MAX696x_CONF_H_
//-------------------------------------------------------
// USER CONFIGURATIONS FOR MAX696x LIBRARY FOR ARDUINO
// 
// Compatible with following devices:
// - MAX6960, MAX6961, MAX6962, MAX6963 
//
// Please refer to datasheets for specific limitiations 
// and features of each device.
//
// The #defines in this section should be set to match your
// display and arduino hardware configurations
//
// NOTE: IF YOU MAKE ANY CHANGES TO THIS FILE THEN YOU 
// MUST DELETE THE FOLLOWING FILE AND RECOMPILE/VERIFY:
//
// <arduino base directory>/hardware/libraries/max696x/max696x.o

//-------------------------------------------------------
// MAX696x_DEBUG
//
// Set to 1 to enable debug output from the max696x library
// Set to 0 to disable debug output 

// Debug mode enables printing to the standard serial port of
// various data and status messages.
//
// It also compiles in extra test strings into program memory
// and consumes extra resorces and RAM to run.
//
// Setting this to 1 also enables the following functons:
// max696x::reg_dump()

#define MAX696x_DEBUG   (1)

//-------------------------------------------------------
// MAX696x_USE_HW_SPI 
//
// Set to 1 to use hardware SPI, otherwise set to 0 to 
// use bit-bashed SPI driver on what ever pins you've 
// set below

#define MAX696x_USE_HW_SPI     (1)

// Define the SPI I/O pins for the Arduino Diecimila
#if MAX696x_USE_HW_SPI == 1
// Default pin assignments for hardware SPI
#define DATAOUT      (11)  //MOSI
#define DATAIN       (12)  //MISO 
#define SPICLOCK     (13)  //sck
#define SLAVESELECT  (10)  //ss
#else
// Select your own pin assignments for bit-bashed SPI
#define DATAOUT      (11)  //MOSI
#define DATAIN       (12)  //MISO 
#define SPICLOCK     (13)  //sck
#define SLAVESELECT  (10)  //ss
#endif // MAX696x_USE_HW_SPI == 1

// select your own RESET and INTERRUPT pin assignments

#define RESET         (9)
#define INTERRUPT     (8)

//-------------------------------------------------------
// Port and bit definitions for bit bashed SPI
// these must match up with the definitions above
// Consult the Arduino/ATMEGA168 data sheets for more information.

#define SPICLOCK_PORT    (PORTB)
#define SPICLOCK_BIT     (PB5)
#define DATAIN_PORT      (PINB)
#define DATAIN_BIT       (PB4)
#define DATAOUT_PORT     (PORTB)
#define DATAOUT_BIT      (PB3)
#define SLAVESELECT_PORT (PORTB)
#define SLAVESELECT_BIT  (PB2)
#define RESET_PORT       (PORTB)
#define RESET_BIT        (PB1)
#define INTERRUPT_PORT   (PINB)
#define INTERRUPT_BIT    (PB0)

//-------------------------------------------------------
// User settings
//
// The #defines in this section should be set to match your
// display hardware configuration

// Set the following to the total number of daisy chained
// devices in the display
#define NUMBER_OF_DRIVER_DEVICES    (2)

// Set the following to the number of devices per row
#define NUMBER_OF_DRIVERS_PER_ROW   (2)

// MAX696x_OSC_FREQ - MAX696x OSC clock frequency in Hz
#define MAX696x_OSC_FREQ            (8100800)

// FRAME_AUTO 
// (1) -> enable automatic disply plane cycling
// (0) -> disable automatic disply plane cycling
#define FRAME_AUTO                  (1)

// FRAME_SPEED
// (1) -> frame rate 1 FPS or greater ie greater than 1 Hz update rate
// (0) -> frame rate less tham 1 FPS ie less than 1 Hz update rate
// 
// See also FRAME_RATE_FPS below
#define FRAME_SPEED                 (1)

// FRAME_RATE_FPS - sets the frame rate of the display use whole numbers here.
//
// Note that the interpretation of this value is dependent on the setting 
// of FRAME_SPEED above, eg:
//
// FRAME_SPEED = (1)
// FRAME_RATE_FPS = (25) -> 25 frames per sec, ie new frame every 40 msec
//
// FRAME SPEED = (0)
// FRAME_RATE_FPS = (25) -> 0.04 frames per sec, ie new frame every 25 seconds
//
// Note that actual frame rate will not be exactly what is requested
// here due to rounding, but will be fairly close
#define FRAME_RATE_FPS              (50)

// Set the following to the mode of operation either:
// mono : MODE_MONO
// RYG  : MODE_RYG
// RGB  : MODE_RGB
#define MAX_696x_MODE               (MODE_MONO)

#endif // _MAX696x_CONF_H_
